/* -*- Mode: C; c-file-style: "gnu" -*-
   component.c -- native methods for sun/awt/motif/MComponentPeer
   Created: Chris Toshok <toshok@hungry.com>, 3-Mar-1998.
 */
/*
  This file is part of Japhar, the GNU Virtual Machine for Java Bytecodes.
  Japhar is a project of The Hungry Programmers, GNU, and OryxSoft.

  Copyright (C) 1998 The Hungry Programmers

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */

#include "jni.h"

#include "common.h"

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pInitialize(JNIEnv *env,
					      jobject peer)
{
  printf ("In sun_awt_motif_MComponentPeer_pInitialize(peer = %p)\n", peer);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pShow(JNIEnv *env,
					jobject peer)
{
  Widget w = get_component_widget(env, peer);

  printf ("in sun_awt_motif_MComponentPeer_pShow(peer = %p)\n", peer);

  LOCK_AWT();
  XtManageChild(w);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pHide(JNIEnv *env,
					jobject peer)
{
  Widget w = get_component_widget(env, peer);

  printf ("in sun_awt_motif_MComponentPeer_pHide(peer = %p)\n", peer);

  LOCK_AWT();
  XtUnmanageChild(w);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pEnable(JNIEnv *env,
					  jobject peer)
{
  Widget w = get_component_widget(env, peer);

  LOCK_AWT();
  XtSetSensitive(w, True);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pDisable(JNIEnv *env,
					   jobject peer)
{
  Widget w = get_component_widget(env, peer);

  LOCK_AWT();
  XtSetSensitive(w, False);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pReshape(JNIEnv *env,
					   jobject peer,
					   jint x,
					   jint y,
					   jint width,
					   jint height)
{
  Widget widget = get_component_widget(env, peer);

  LOCK_AWT();
  XtVaSetValues(widget,
		XmNx, x,
		XmNy, y,
		XmNwidth, width,
		XmNheight, height,
		NULL);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pAddRepaint(JNIEnv *env,
					      jobject peer,
					      jint x,
					      jint y,
					      jint width,
					      jint height)
{
  printf ("In sun_awt_motif_MComponentPeer_pAddRepaint(peer = %p, x = %d, y = %d, width = %d, height = %d)\n",
	  peer, x, y, width, height);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pTriggerRepaint(JNIEnv *env,
						  jobject peer)
{
  printf ("In sun_awt_motif_MComponentPeer_pTriggerRepaint(peer = %p)\n", peer);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pDispose(JNIEnv *env,
					   jobject peer)
{
  Widget w = get_component_widget(env, peer);

  printf ("In sun_awt_motif_MComponentPeer_pDispose(peer = %p)\n", peer);

  LOCK_AWT();
  XtDestroyWidget(w);
  UNLOCK_AWT();
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_pMakeCursorVisible(JNIEnv *env,
						     jobject peer)
{
  printf ("In sun_awt_motif_MComponentPeer_pMakeCursorVisible(peer = %p)\n", peer);
}

JNIEXPORT jobject JNICALL
Java_sun_awt_motif_MComponentPeer_pGetLocationOnScreen(JNIEnv *env,
						       jobject peer)
{
  printf ("In sun_awt_motif_MComponentPeer_pGetLocationOnScreen(peer = %p)\n", peer);
  return NULL;
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_setForeground(JNIEnv *env,
						jobject peer,
						jobject foreground)
{
  jclass color = (*env)->GetObjectClass(env, foreground);
  jmethodID getRed = (*env)->GetMethodID(env, color, "getRed", "()I");
  jmethodID getGreen = (*env)->GetMethodID(env, color, "getGreen", "()I");
  jmethodID getBlue = (*env)->GetMethodID(env, color, "getBlue", "()I");
  jint red, green, blue;

  red = (*env)->CallIntMethod(env, foreground, getRed);
  green = (*env)->CallIntMethod(env, foreground, getGreen);
  blue = (*env)->CallIntMethod(env, foreground, getBlue);

  printf ("In sun_awt_motif_MComponentPeer_setForeground(peer = %p, foreground = %p)\n", peer, foreground);
  printf ("red = %d, green = %d, blue = %d\n", red, green, blue);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_setBackground(JNIEnv *env,
						jobject peer,
						jobject background)
{
  jclass color = (*env)->GetObjectClass(env, background);
  jmethodID getRed = (*env)->GetMethodID(env, color, "getRed", "()I");
  jmethodID getGreen = (*env)->GetMethodID(env, color, "getGreen", "()I");
  jmethodID getBlue = (*env)->GetMethodID(env, color, "getBlue", "()I");
  jint red, green, blue;

  red = (*env)->CallIntMethod(env, background, getRed);
  green = (*env)->CallIntMethod(env, background, getGreen);
  blue = (*env)->CallIntMethod(env, background, getBlue);

  printf ("In sun_awt_motif_MComponentPeer_setBackground(peer = %p, background = %p)\n", peer, background);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_setFont(JNIEnv *env,
					  jobject peer,
					  jobject font)
{
  printf ("In sun_awt_motif_MComponentPeer_setFont(peer = %p, font = %p)\n", peer, font);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_setCursor(JNIEnv *env,
					    jobject peer,
					    jobject cursor)
{
  Widget w = get_component_widget(env, peer);
  jclass cursor_class = (*env)->GetObjectClass(env, cursor);
  jfieldID type;
  jint cursor_type;

  printf ("In sun_awt_motif_MComponentPeer_setCursor(peer = %p, cursor = %p)\n", peer, cursor);

  type = (*env)->GetFieldID(env, cursor_class, "type", "I");
  cursor_type = (*env)->GetIntField(env, cursor, type);

  printf ("+  cursor_type = %d\n", cursor_type);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_handleEvent(JNIEnv *env,
					      jobject peer,
					      jobject event)
{
  printf ("In sun_awt_motif_MComponentPeer_handleEvent(peer = %p, event = %p)\n", peer, event);
}

JNIEXPORT void JNICALL
Java_sun_awt_motif_MComponentPeer_requestFocus(JNIEnv *env,
					       jobject peer)
{
  printf ("In sun_awt_motif_MComponentPeer_requestFocus(peer = %p)\n", peer);
}
